@@ -380,7 +380,7 @@ FormulaToken* ScRawToken::CreateToken() const
             IF_NOT_OPCODE_ERROR( ocPush, ScMatrixToken);
             return new ScMatrixToken( pMat );
         case svIndex :
-            return new ScNameToken(name.nIndex, name.bGlobal);
+            return new ScNameToken(name.nIndex, name.bGlobal, eOp);
         case svExternalSingleRef:
             {
                 String aTabName(extref.cTabName);
@@ -949,8 +949,8 @@ bool ScExternalDoubleRefToken::operator ==( const FormulaToken& r ) const
 
 // ============================================================================
 
-ScNameToken::ScNameToken(sal_uInt16 nIndex, bool bGlobal) :
-    ScToken(svIndex, ocName), mnIndex(nIndex), mbGlobal(bGlobal) {}
+ScNameToken::ScNameToken(sal_uInt16 nIndex, bool bGlobal, OpCode eOpCode) :
+    ScToken(svIndex, eOpCode), mnIndex(nIndex), mbGlobal(bGlobal) {}
 
 ScNameToken::ScNameToken(const ScNameToken& r) :
     ScToken(r), mnIndex(r.mnIndex), mbGlobal(r.mbGlobal) {}
